unit untWriteForm;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, ComCtrls, OleCtrls, SHDocVw, StdCtrls, untTopic,
  untGlobal, SHDocVw_TLB, untBBSCore, untBoard, untOption;

type
  TWriteForm = class(TForm)
    PageControl1: TPageControl;
    TabSheet1: TTabSheet;
    TabSheet2: TTabSheet;
    WebBrowser1: TWebBrowser;
    Label1: TLabel;
    TitleEdit: TEdit;
    Label2: TLabel;
    NameComboBox: TComboBox;
    Label3: TLabel;
    EmailComboBox: TComboBox;
    BodyMemo: TMemo;
    SageCheckBox: TCheckBox;
    WriteButton: TButton;
    CancelButton: TButton;
    procedure FormDeactivate(Sender: TObject);
    procedure FormActivate(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure WriteButtonClick(Sender: TObject);
    procedure CancelButtonClick(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure SageCheckBoxClick(Sender: TObject);
  private
    { Private 錾 }
    FMakeTopicMode : Boolean;
    FFormHeight : Integer;
    FTopic      : TTopic;
    FBoard      : TOnlineBoard;
    procedure BoardStateChange (Board : TBoard; EventType : TBoardStateType);
  public
    { Public 錾 }
    procedure SetTopic(Topic : TTopic);
    procedure SetBoard(Board : TOnlineBoard);
  end;

var
  WriteForm: TWriteForm;

implementation

{$R *.dfm}

procedure TWriteForm.FormDeactivate(Sender: TObject);
begin
  //
  FFormHeight := self.Height;
  self.Height := 0;

end;

procedure TWriteForm.FormActivate(Sender: TObject);
begin
  //
  self.Height := FFormHeight;
end;

procedure TWriteForm.FormCreate(Sender: TObject);
begin
  FFormHeight := self.Height;
  gBBSCore.AddBoardStateChangeEvent(BoardStateChange);
end;


procedure TWriteForm.FormDestroy(Sender: TObject);
begin
  gBBSCore.RemoveBoardStateChangeEvent(BoardStateChange);
  if FTopic <> nil then
    FTopic.CountDown;
end;


procedure TWriteForm.WriteButtonClick(Sender: TObject);
begin

  if EmailComboBox.Text = 'sage' then
    gDefaultSage := true
  else if EmailComboBox.Text = '' then
    gDefaultSage := false;

  if FMakeTopicMode = false then
  begin
    FTopic.WroteName  := NameComboBox.Text;
    FTopic.WroteEmail := EmailComboBox.Text;
    FTopic.SaveIdx;
    gBBSCore.PostArticle(FBoard, FTopic.TopicId, NameComboBox.Text, EmailComboBox.Text, BodyMemo.Text);
  end else
  begin
    gBBSCore.MakeTopic(FBoard, TitleEdit.Text, NameComboBox.Text, EmailComboBox.Text, BodyMemo.Text);
  end;

end;

procedure TWriteForm.SetTopic(Topic: TTopic);
begin

  if self.Visible = true then
  begin
    self.Show;
    exit;
  end;

  Topic.CountUp;
  FMakeTopicMode := false;
  FTopic := Topic;
  FBoard := TOnlineBoard(Topic.Board);
  self.Caption := 'u' + FTopic.Title + 'vɃX';
  TitleEdit.Text := FTopic.Title;
  TitleEdit.Enabled := false;
  NameComboBox.Text := FTopic.WroteName;
  EmailComboBox.Text := FTopic.WroteEmail;
  if EmailComboBox.Text = '' then
    if gDefaultSage = true then
      EmailComboBox.Text := 'sage';
  SageCheckBox.Checked := (EmailComboBox.Text = 'sage');
  SageCheckBoxClick(SageCheckBox);
  BodyMemo.Text := '';

  self.Show;

end;

procedure TWriteForm.SetBoard(Board: TOnlineBoard);
begin

  if self.Visible = true then
  begin
    self.Show;
    exit;
  end;

  FMakeTopicMode := true;
  FBoard := Board;
  self.Caption := 'u' + FBoard.DisplayName + 'vɐVKXbh';
  TitleEdit.Text := '';
  TitleEdit.Enabled := true;
  NameComboBox.Text := '';
  EmailComboBox.Text := '';
  if EmailComboBox.Text = '' then
    if gDefaultSage = true then
      EmailComboBox.Text := 'sage';
  SageCheckBox.Checked := (EmailComboBox.Text = 'sage');
  SageCheckBoxClick(SageCheckBox);
  BodyMemo.Text := '';

  self.Show;

end;




procedure TWriteForm.CancelButtonClick(Sender: TObject);
begin
  Close;
end;

procedure TWriteForm.BoardStateChange(Board: TBoard;
  EventType: TBoardStateType);
var
  ErrorMsg : string;
begin

  if FBoard <> Board then exit;

  if EventType <> bsWriteDone then exit;
  ErrorMsg := TOnlineBoard(Board).WriteError;

  if ErrorMsg = '' then
  begin
    if FMakeTopicMode = false then
    begin
      FTopic.LastWriteDate := DateTimeToStr(Now());
      FTopic.SaveIdx;
      gBBSCore.DownloadTopic(FTopic);
    end;

    Close;
  end else
    ShowMessage(ErrorMsg);

end;

procedure TWriteForm.SageCheckBoxClick(Sender: TObject);
begin
  if SageCheckBox.Checked then
  begin
    EmailComboBox.Text := 'sage';
    EmailComboBox.Enabled := false;
  end else
  begin
    EmailComboBox.Text := '';
    EmailComboBox.Enabled := true;    
  end;
    
end;

end.
